# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

try:
    from .multi_language_input_py3 import MultiLanguageInput
    from .multi_language_batch_input_py3 import MultiLanguageBatchInput
    from .match_record_py3 import MatchRecord
    from .entity_record_py3 import EntityRecord
    from .document_statistics_py3 import DocumentStatistics
    from .entities_batch_result_item_py3 import EntitiesBatchResultItem
    from .error_record_py3 import ErrorRecord
    from .request_statistics_py3 import RequestStatistics
    from .entities_batch_result_py3 import EntitiesBatchResult
    from .internal_error_py3 import InternalError
    from .error_response_py3 import ErrorResponse, ErrorResponseException
    from .key_phrase_batch_result_item_py3 import KeyPhraseBatchResultItem
    from .key_phrase_batch_result_py3 import KeyPhraseBatchResult
    from .language_input_py3 import LanguageInput
    from .language_batch_input_py3 import LanguageBatchInput
    from .detected_language_py3 import DetectedLanguage
    from .language_batch_result_item_py3 import LanguageBatchResultItem
    from .language_batch_result_py3 import LanguageBatchResult
    from .sentiment_batch_result_item_py3 import SentimentBatchResultItem
    from .sentiment_batch_result_py3 import SentimentBatchResult
except (SyntaxError, ImportError):
    from .multi_language_input import MultiLanguageInput
    from .multi_language_batch_input import MultiLanguageBatchInput
    from .match_record import MatchRecord
    from .entity_record import EntityRecord
    from .document_statistics import DocumentStatistics
    from .entities_batch_result_item import EntitiesBatchResultItem
    from .error_record import ErrorRecord
    from .request_statistics import RequestStatistics
    from .entities_batch_result import EntitiesBatchResult
    from .internal_error import InternalError
    from .error_response import ErrorResponse, ErrorResponseException
    from .key_phrase_batch_result_item import KeyPhraseBatchResultItem
    from .key_phrase_batch_result import KeyPhraseBatchResult
    from .language_input import LanguageInput
    from .language_batch_input import LanguageBatchInput
    from .detected_language import DetectedLanguage
    from .language_batch_result_item import LanguageBatchResultItem
    from .language_batch_result import LanguageBatchResult
    from .sentiment_batch_result_item import SentimentBatchResultItem
    from .sentiment_batch_result import SentimentBatchResult

__all__ = [
    'MultiLanguageInput',
    'MultiLanguageBatchInput',
    'MatchRecord',
    'EntityRecord',
    'DocumentStatistics',
    'EntitiesBatchResultItem',
    'ErrorRecord',
    'RequestStatistics',
    'EntitiesBatchResult',
    'InternalError',
    'ErrorResponse', 'ErrorResponseException',
    'KeyPhraseBatchResultItem',
    'KeyPhraseBatchResult',
    'LanguageInput',
    'LanguageBatchInput',
    'DetectedLanguage',
    'LanguageBatchResultItem',
    'LanguageBatchResult',
    'SentimentBatchResultItem',
    'SentimentBatchResult',
]
