# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MultiLanguageBatchInput(Model):
    """MultiLanguageBatchInput.

    :param documents:
    :type documents:
     list[~azure.cognitiveservices.language.textanalytics.models.MultiLanguageInput]
    """

    _attribute_map = {
        'documents': {'key': 'documents', 'type': '[MultiLanguageInput]'},
    }

    def __init__(self, **kwargs):
        super(MultiLanguageBatchInput, self).__init__(**kwargs)
        self.documents = kwargs.get('documents', None)
