# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ErrorRecord(Model):
    """ErrorRecord.

    :param id: Input document unique identifier the error refers to.
    :type id: str
    :param message: Error message.
    :type message: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ErrorRecord, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.message = kwargs.get('message', None)
